betty.extension.cotton_candy.search module - Betty 0.4.0a4 documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# betty.extension.cotton_candy.search module

Provide Cotton Candy’s search functionality.

class betty.extension.cotton_candy.search.Index

  Bases: `object`

  Build search indexes.

  __init__(project: Project, job_context: Context | None, localizer: Localizer)
  async build() → AsyncIterable[dict[str, str]]

    Build the search index.